# eric7.WebBrowser.OpenSearch.OpenSearchWriter

Module implementing a writer for open search engine descriptions.

### Global Attributes

None

### Classes

OpenSearchWriter | Class implementing a writer for open search engine descriptions.

### Functions

None

## OpenSearchWriter

Class implementing a writer for open search engine descriptions.

### Derived from

QXmlStreamWriter

### Class Attributes

None

### Class Methods

None

### Methods

OpenSearchWriter | Constructor
__write | Private method to write the description of an engine.
write | Public method to write the description of an engine.

### Static Methods

None

#### OpenSearchWriter (Constructor)

OpenSearchWriter()

Constructor

#### OpenSearchWriter.__write

__write(engine)

Private method to write the description of an engine.

engine (OpenSearchEngine)
  reference to the engine

#### OpenSearchWriter.write

write(device, engine)

Public method to write the description of an engine.

device (QIODevice)
  reference to the device to write to
engine (OpenSearchEngine)
  reference to the engine

Return:
  flag indicating success

Return Type:
  bool

Up